<ion-header>

  <ion-navbar>
    <ion-title>Login</ion-title>
  </ion-navbar>

</ion-header>


<ion-content>
    <ion-list>
      <div padding>
        {{userData | json}}
      </div>
      <div padding>
        <button *ngIf="!isAuthorized" ion-button (click)="login()" block>Login</button>
        <button *ngIf="isAuthorized" ion-button (click)="logout()" block>Logout</button>
      </div>

    </ion-list>
</ion-content>
